summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtexturemapedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtexturemapedit.h')
-rw-r--r--kpovmodeler/pmtexturemapedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmtexturemapedit.h b/kpovmodeler/pmtexturemapedit.h
index 7ca57401..4a8f3c19 100644
--- a/kpovmodeler/pmtexturemapedit.h
+++ b/kpovmodeler/pmtexturemapedit.h
@@ -43,9 +43,9 @@ class PMTextureMapEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMTextureMapEdit with tqparent and name
*/
- PMTextureMapEdit( TQWidget* tqparent, const char* name = 0 );
+ PMTextureMapEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -43,9 +43,9 @@ class PMTextureMapEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMTextureMapEdit with tqparent and name
+ * Creates a PMTextureMapEdit with parent and name
*/